@@ -1,7 +1,7 @@
 package Dist::Util::Debian;
 
-our $DATE = '2017-01-17'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2017-01-18'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -47,7 +47,7 @@ sub _deb_exists_or_deb_ver {
             File::Slurper::Temp::write_text($path, $uncompressed);
         }
         my %versions;
-        my $re = join("|", map { quotemeta($_) } @_); $re = qr/^($re) \(([^\)]+)\)/;
+        my $re = join("|", map { quotemeta($_) } @_); $re = qr/^($re) \(([^\)]+?)(?:\)|\s)/;
         open my($fh), "<", $path or die "Can't open $path: $!";
         while (defined(my $line = <$fh>)) {
             if ($line =~ $re) {
@@ -68,7 +68,7 @@ sub _deb_exists_or_deb_ver {
             if ($res->{content} =~ /No such package/) {
                 push @res, $which eq 'deb_exists' ? 0 : undef;
                 next;
-            } elsif ($res->{content} =~ /Package: \Q$deb\E \(([^\)]+)\)/) {
+            } elsif ($res->{content} =~ /Package: \Q$deb\E \(([^\)]+?)(?:\)|\s)/) {
                 push @res, $which eq 'deb_exists' ? 1 : $1;
                 next;
             } else {
@@ -117,7 +117,7 @@ Dist::Util::Debian - Utilities related to Perl distribution and Debian
 
 =head1 VERSION
 
-This document describes version 0.005 of Dist::Util::Debian (from Perl distribution Dist-Util-Debian), released on 2017-01-17.
+This document describes version 0.006 of Dist::Util::Debian (from Perl distribution Dist-Util-Debian), released on 2017-01-18.
 
 =head1 SYNOPSIS
 
